View source: R/eligibility_rate.R
| eligibility_rate | R Documentation |
Provides an estimate for the proportion of cases of unknown eligibility that are eligible, as described by \insertCitevdkoutcomerate. The rate is typically (but not necessarily) calculated on the screener data or other sources depending on the type of survey, and approaches to calculating 'e' may therefore differ from one survey to the next.
eligibility_rate(x, weight = NULL)
x |
a character vector of disposition outcomes (I, P, R, NC, O, UH, UR, UO, or NE). Alternatively, a named vector/table of (weighted) disposition counts. |
weight |
an optional numeric vector that specifies the weight of each element in 'x' if x is a character vector. For probability samples, these will normally be base weights (inverse selection probabilities). If none is provided (the default), an unweighted estimate is returned. Weights cannot be supplied with an already-aggregated named vector or table. |
The present proportional-allocation implementation follows the default used
in the Excel-based AAPOR Outcome Rate Calculator (Version 5.1, April 2023),
on the basis of known ineligibles being coded as "NE". It is one accepted
estimator of e; researchers should use better design-specific information
when available. This function returns one scalar estimate. Separate
estimates can be supplied directly to outcomerate() as a named vector such
as c(UH = 0.4, UR = 0.7, UO = 0.2); they cannot be inferred from the
package's aggregate NE count alone. See
\insertCiteaapor_e_2025outcomerate for category-specific estimation
guidance.
The eligibility rate (ELR) is defined as
ELR = (I + P + R + NC + O) / (I + P + R + NC + O + NE)
A named numeric vector of length one containing the estimated
eligibility rate, named ELR.
aaporoutcomerate \insertAllCited
outcomerate
# load the outcomerate package
library(outcomerate)
# Create a vector of survey dispositions
#
# I = Complete interview
# P = Partial interview
# R = Refusal and break-off
# NC = Non-contact
# O = Other eligible non-interview (2.30, 2.90)
# UH = Unknown if household/occupied housing unit (3.10)
# UR = Unknown if sampled unit is eligible/housing unit contains an eligible
# respondent (3.20)
# UO = Unknown, other (3.90)
# NE = Not eligible (4.0)
x <- c("I", "P", "I", "NE", "NC", "UH", "I", "R", "UR", "UO", "I", "O",
"P", "I")
# estimate the eligibility rate
eligibility_rate(x)
# calculate a weighted rate using illustrative base weights
w <- seq(0.5, 1.8, length.out = length(x))
eligibility_rate(x, weight = w)
# alternatively, provide input as counts
freq <- c(I = 6, P = 2, NC = 3, NE = 1)
eligibility_rate(freq)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.